@@ -8,7 +8,7 @@ function (x, digits = max(3, getOption("digits") - 2),
                             P.values = NULL,
                             has.Pvalue = nc >= 4 && substr(colnames(x)[nc], 1, 3) == "Pr(",
                             eps.Pvalue = .Machine$double.eps,
-                            na.print = "NA",  ...) 
+                            na.print = "NA", pval = TRUE, ...) 
 {
     if (is.null(d <- dim(x)) || length(d) != 2L) 
         stop("'x' must be coefficient matrix/data frame")
@@ -16,7 +16,8 @@ function (x, digits = max(3, getOption("digits") - 2),
     xm <- data.matrix(x)
 
     Cf <- array("", dim = d, dimnames = dimnames(xm))
-    Cf[,1:3] <- format(x[,1:3], digits=dig.tst)
+    if(pval == TRUE) {
+        Cf[,1:(nc-1)] <- format(x[,1:(nc-1)], digits=dig.tst)
     
             pv <- as.vector(xm[, nc])
             Cf[, nc] <- format.pval(pv, digits = dig.tst, 
@@ -27,12 +28,14 @@ function (x, digits = max(3, getOption("digits") - 2),
                   cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1), 
                   symbols = c("***", "**", "*", ".", " "))
                 Cf <- cbind(Cf, format(Signif))
-
+    } else {
+        Cf[,1:(nc)] <- format(x[,1:(nc)], digits=dig.tst)
+    }
 
     print.default(Cf, quote = FALSE, right = TRUE, na.print = na.print, 
         ...)
 
-        cat("---\nSignif. codes: ", attr(Signif, "legend"), "\n")
+    if(pval == TRUE)  cat("---\nSignif. codes: ", attr(Signif, "legend"), "\n")
     invisible(x)
 }
 
